(function() {
	/**
	 * 插槽支持
	 * @param VNode
	 * @param children
	 * @param host
	 */
	function slotSupport(VNode, children, host) {
		var slots = {
			default: []
		};

		var dfsScope = function dfsScope(node) {
			if (node.nodeName === "text" && node.attributes) {
				var text = node.children[0];
				if (
					node.attributes.scoped ||
					(typeof text === "string" && text.startsWith("[[") && text.endsWith("]]"))
				) {
					var path = text.replace(/[\[\]]/g, "").split(/[.[]/);
					if (node.attributes.scoped) {
						path = node.attributes.scoped;
					} else {
						node.attributes.scoped = path;
					}
					var data = host;
					path.forEach(function(p) {
						return (data = data[p]);
					});
					node.children[0] = JSON.stringify(data);
				}
			}

			if (Array.isArray(node.children) && node.children.length) {
				node.children.forEach(dfsScope);
			}
		};

		children.forEach(function(node) {
			if (node) {
				if (
					node.nodeName === "template" &&
					node.attributes &&
					node.attributes._slot
				) {
					var slotInfo = node.attributes._slot.split(":");
					if (slotInfo.length === 2) {
						node.attributes.scope = slotInfo[1];
						node.attributes._slot = slotInfo[0];
					}
					slots[node.attributes._slot] = node;
				} else {
					slots.default.push(node);
				}
				dfsScope(node);
			}
		});

		if (Object.keys(slots).length === 1 && slots.default.length === 0) {
			// 没有 slot 项目 直接返回 不要再去查找组件
			return VNode;
		}

		var dfs = function dfs(node) {
			if (node.attributes && node.attributes._slot) {
				if (slots[node.attributes._slot]) {
					if (node.attributes._slot === "default") {
						node.children = [].concat(node.children, slots[node.attributes._slot]);
					} else {
						node.children = slots[node.attributes._slot].children;
						node.attributes = Object.assign(
							slots[node.attributes._slot].attributes,
							node.attributes
						);
					}
				}
				// delete node.attributes._slot;
			} else if (Array.isArray(node.children) && node.children.length) {
				node.children.forEach(dfs);
			}
		};
		dfs(VNode);

		return VNode;
	}

	/**
	 * 继承父组件的 class 、style
	 * @param VNode
	 * @param props
	 * @returns {*}
	 */
	function extendsClassStyle(VNode, props) {
		props.class && (VNode.attributes.class += " " + props.class);
		props.style && (VNode.attributes.style = props.style);
		return VNode;
	}

	/**
	 * 超级节点
	 * @param VNode
	 * @param props
	 * @returns {*}
	 */
	function superNode(VNode, props) {
		slotSupport(VNode, props.children);
		extendsClassStyle(VNode, props);
		// extendsEvent(VNode, props);
		// console.log('superNode', VNode)
		return VNode;
	}

	/**
	 * 混合class类
	 * @param cls
	 * @param extra
	 * @returns {string}
	 */
	function mixedClass(cls, extra) {
		if (!extra) {
			return cls;
		} else {
			var classList = [cls];
			Object.entries(extra).forEach(function(_ref2) {
				var key = _ref2[0],
					val = _ref2[1];
				return val && classList.push(key);
			});
			return classList.join(" ");
		}
	}

	var AIcon = /*@__PURE__*/ (function(Component) {
		function AIcon(props) {
			Component.call(this, props);
		}

		if (Component) AIcon.__proto__ = Component;
		AIcon.prototype = Object.create(Component && Component.prototype);
		AIcon.prototype.constructor = AIcon;
		AIcon.prototype.install = function() {
			this.render = function(props) {
				if (!props.size) {
					props.size = 16;
				}
				if (!props.scale) {
					props.scale = 2;
				} //2倍缩放 适配高分屏
				if (!props.color) {
					props.color = "#666";
				}
				props.color = props.color.replace("#", "_");

				var isImage = props.name.includes("/");

				var src = isImage
					? props.name
					: "http://icon.yangyongan.com/?name=" +
					  props.name +
					  "&color=" +
					  props.color +
					  "&size=" +
					  props.size +
					  "&scale=" +
					  props.scale;

				var h = apivm.h;

				var renderIcon = h(
					"img",
					Object.assign({}, props, {
						class:
							"a-icon a-icon__" +
							(isImage ? "image" : props.name) +
							" " +
							(props.class || ""),
						style:
							"width:" +
							props.size +
							"px;height:" +
							props.size +
							"px;" +
							(props.style || ""),
						src: src
					})
				);

				if (props.dot) {
					return h(
						"view",
						{
							class: "a-icon__wrapper a-icon__dot"
						},
						renderIcon,
						h("view", {class: "a-icon__dot"})
					);
				} else if (props.badge) {
					return h(
						"view",
						{
							class: "a-icon__wrapper a-icon__badge"
						},
						renderIcon
					);
				} else {
					return renderIcon;
				}
			};
		};
		AIcon.prototype.render = function() {
			return;
		};

		return AIcon;
	})(Component);
	AIcon.css = {
		".a-icon": {alignSelf: "center"},
		".a-icon__dot": {
			width: "8px",
			minWidth: "0",
			height: "8px",
			backgroundColor: "#ee0a24",
			borderRadius: "100%"
		}
	};
	apivm.define("a-icon", AIcon);

	var ANavBar = /*@__PURE__*/ (function(Component) {
		function ANavBar(props) {
			Component.call(this, props);
		}

		if (Component) ANavBar.__proto__ = Component;
		ANavBar.prototype = Object.create(Component && Component.prototype);
		ANavBar.prototype.constructor = ANavBar;
		ANavBar.prototype.install = function() {
			api.setStatusBarStyle &&
				api.setStatusBarStyle({
					style: "dark",
					color: "-"
				});
		};
		ANavBar.prototype.leftClick = function(ev) {
			ev.stopPropagation ? ev.stopPropagation() : (ev.cancelBubble = true);
			if (this.props["onClick-left"]) {
				this.fire("click-left", ev);
			} else {
				api.closeWin();
			}
		};
		ANavBar.prototype.rightClick = function(ev) {
			ev.stopPropagation ? ev.stopPropagation() : (ev.cancelBubble = true);
			this.fire("click-right", ev);
		};
		ANavBar.prototype.titleClick = function(ev) {
			this.fire("title-right", ev);
		};
		ANavBar.prototype.render = function() {
			return superNode(
				apivm.h(
					"safe-area",
					{
						class: "a-nav-bar" + (!this.props["hide-line"] ? " a-nav-bar--line" : "")
					},
					apivm.h(
						"view",
						{
							class: "a-nav-bar__content",
							style: "height: " + (this.props["height"] || 46) + "px"
						},

						this.props["left-arrow"]
							? apivm.h(
									"view",
									{
										class: "a-nav-bar__click-warp a-nav-bar__left",
										_slot: "left",
										onClick: this.leftClick
									},
									this.props["left-arrow"] &&
										apivm.h(AIcon, {
											name: "arrow-left",
											class: "a-nav-bar__icon",
											color: "#333"
										}),
									this.props["left-text"] &&
										apivm.h("text", {class: "a-nav-bar__text"}, this.props["left-text"])
							  )
							: null,

						apivm.h(
							"text",
							{
								class: "a-nav-bar__title",
								style:
									"font-size: " +
									(this.props["title-size"] || 16) +
									"px;color: " +
									(this.props["title-color"] || "#000") +
									";",
								onClick: this.titleClick
							},
							this.props["title"]
						),

						apivm.h(
							"view",
							{
								class: "a-nav-bar__click-warp a-nav-bar__right",
								_slot: "right",
								onClick: this.rightClick
							},
							apivm.h("text", {class: "a-nav-bar__text"}, this.props["right-text"])
						)
					)
				),
				this.props
			);
		};

		return ANavBar;
	})(Component);
	ANavBar.css = {
		".a-nav-bar": {backgroundColor: "#fff"},
		".a-nav-bar--line": {boxShadow: "1px 1px 1px #e6e6e6", marginBottom: "2px"},
		".a-nav-bar__content": {flexFlow: "row nowrap"},
		".a-nav-bar__click-warp": {
			position: "absolute",
			height: "100%",
			flexFlow: "row nowrap",
			alignItems: "center",
			padding: "0 16px",
			zIndex: "99"
		},
		".a-nav-bar__left": {left: "0"},
		".a-nav-bar__right": {right: "0"},
		".a-nav-bar__text": {color: "#333", fontSize: "14px"},
		".a-nav-bar__icon": {height: "16px", width: "16px"},
		".a-nav-bar__title": {
			display: "flex",
			justifyContent: "center",
			alignItems: "center",
			flex: "1",
			alignSelf: "center",
			textAlign: "center",
			fontWeight: "500",
			whiteSpace: "nowrap",
			textOverflow: "ellipsis",
			overflow: "hidden"
		}
	};
	apivm.define("a-nav-bar", ANavBar);

	var AButton = /*@__PURE__*/ (function(Component) {
		function AButton(props) {
			Component.call(this, props);
		}

		if (Component) AButton.__proto__ = Component;
		AButton.prototype = Object.create(Component && Component.prototype);
		AButton.prototype.constructor = AButton;
		AButton.prototype.install = function() {
			var h = avm.h;

			this.render = function(props) {
				var obj;

				if (!props.type) {
					props.type = "default";
				}
				if (!props.size) {
					props.size = "normal";
				}

				if (props.icon) {
					props.children.unshift({
						nodeName: AIcon,
						attributes: {name: props.icon, color: "#FFF", size: 20}
					});
				}

				return h(
					"button",
					Object.assign({}, props, {
						class: mixedClass(
							"a-button a-button--" +
								props.type +
								" a-button--" +
								props.size +
								" " +
								(props.class || ""),
							((obj = {}),
							(obj["a-button--plain a-button--plain---a-button--" + props.type] =
								props.plain),
							(obj["a-button--hairline"] = props.hairline),
							(obj["a-button--disabled"] = props.disabled),
							(obj["a-button--square"] = props.square),
							(obj["a-button--round"] = props.round),
							obj)
						)
					}),

					props.text,
					props.children
				);
			};
		};
		AButton.prototype.render = function() {
			return;
		};

		return AButton;
	})(Component);
	AButton.css = {
		".a-button": {
			padding: "0",
			boxSizing: "border-box",
			height: "44px",
			lineHeight: "44px",
			display: "flex",
			alignItems: "center",
			justifyContent: "center",
			textAlign: "center",
			borderRadius: "2px",
			cursor: "pointer",
			WebkitTransition: "opacity 0.2s",
			transition: "opacity 0.2s",
			WebkitAppearance: "none"
		},
		".a-button::after": {border: "none"},
		".a-button--primary": {
			color: "#fff",
			backgroundColor: "#1989fa",
			border: "1px solid #1989fa"
		},
		".a-button--success": {
			color: "#fff",
			backgroundColor: "#07c160",
			border: "1px solid #07c160"
		},
		".a-button--default": {
			color: "#323233",
			backgroundColor: "#fff",
			border: "1px solid #ebedf0"
		},
		".a-button--danger": {
			color: "#fff",
			backgroundColor: "#ee0a24",
			border: "1px solid #ee0a24"
		},
		".a-button--warning": {
			color: "#fff",
			backgroundColor: "#ff976a",
			border: "1px solid #ff976a"
		},
		".a-button--plain": {backgroundColor: "#fff"},
		".a-button--plain---a-button--primary": {color: "#1989fa"},
		".a-button--plain---a-button--success": {color: "#07c160"},
		".a-button--plain---a-button--danger": {color: "#ee0a24"},
		".a-button--plain---a-button--warning": {color: "#ff976a"},
		".a-button--hairline": {borderWidth: "0.5px"},
		".a-button--disabled": {cursor: "not-allowed", opacity: "0.5", color: "#fff"},
		".a-button--round": {borderRadius: "999px"},
		".a-button--square": {borderRadius: "0"},
		".a-button--large": {
			width: "100%",
			height: "50px",
			lineHeight: "50px",
			fontSize: "16px"
		},
		".a-button--normal": {padding: "0 15px", fontSize: "14px"},
		".a-button--small": {
			height: "32px",
			lineHeight: "32px",
			padding: "0 8px",
			fontSize: "12px"
		},
		".a-button--mini": {
			height: "24px",
			lineHeight: "24px",
			padding: "0 4px",
			fontSize: "10px"
		}
	};
	apivm.define("a-button", AButton);

	function ownKeys(object, enumerableOnly) {
		var keys = Object.keys(object);

		if (Object.getOwnPropertySymbols) {
			var symbols = Object.getOwnPropertySymbols(object);

			if (enumerableOnly) {
				symbols = symbols.filter(function(sym) {
					return Object.getOwnPropertyDescriptor(object, sym).enumerable;
				});
			}

			keys.push.apply(keys, symbols);
		}

		return keys;
	}

	function _objectSpread2(target) {
		for (var i = 1; i < arguments.length; i++) {
			var source = arguments[i] != null ? arguments[i] : {};

			if (i % 2) {
				ownKeys(Object(source), true).forEach(function(key) {
					_defineProperty(target, key, source[key]);
				});
			} else if (Object.getOwnPropertyDescriptors) {
				Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
			} else {
				ownKeys(Object(source)).forEach(function(key) {
					Object.defineProperty(
						target,
						key,
						Object.getOwnPropertyDescriptor(source, key)
					);
				});
			}
		}

		return target;
	}

	function _defineProperty(obj, key, value) {
		if (key in obj) {
			Object.defineProperty(obj, key, {
				value: value,
				enumerable: true,
				configurable: true,
				writable: true
			});
		} else {
			obj[key] = value;
		}

		return obj;
	}

	var myParam = {
		domain: "http://xxtbapp.3jidi.com",
		// domain: 'http://192.168.0.102:8081',
		// domain: 'http://192.168.0.176:8085',//教研内网ip
		phone_version: 0,
		apkType: "xx_zw", // 包类型不可变
		myName: "少儿国学写作范文大全",
		// 苹果渠道
		// channelType: 'phone_ios_zw'

		// 安卓渠道
		//channelType: '3jidi_phone_huawei_1'  // 华为
		//channelType: '3jidi_phone_YingYBao_1'// 应用宝
		//channelType: '3jidi_phone_xiaomi_1'  // 小米
		//channelType: '3jidi_phone_360_1'        // 360
		//channelType: '3jidi_phone_baidu_1'   // 百度
		channelType: "3jidi_phone_UC_1" // UC
		//channelType: '3jidi_phone_meizu_1'   // 魅族
		//channelType: '3jidi_phone_samsung_1' // 三星
		// channelType: '3jidi_phone_smartisan_1' // 锤子
		// channelType: '3jidi_phone_lenovo_1'  // 联想
	};

	var count = 0;
	// ajax 方法
	function request(params) {
		// console.log('params---'+JSON.stringify(params));
		count++;
		if (count === 1) {
			api.showProgress();
		}
		return new Promise(function(resolve, reject) {
			//console.log(myParam.domain + params.url);
			api.ajax(
				{
					url: myParam.domain + params.url,
					method: "post",
					cache: false,
					timeout: 3000,
					dataType: "json",
					headers: params.header || {},
					data: {
						values: params.values ? params.values : {},
						files: {
							file: params.file
						}
					},

					returnAll: false
				},
				function(ret, err) {
					// console.log('callback------'+JSON.stringify(ret));
					if (ret) resolve(ret);
					else reject(err);
					count--;
					if (count == 0) {
						api.hideProgress();
					}
				}
			);
		});
	}

	function getDeviceId() {
		return localStorage.getItem("temporaryUid") || api.deviceId;
	}

	// 应用内登录
	function authV2(argFromAuth) {
		if (argFromAuth === void 0) {
			argFromAuth = "";
		}
		opendb_common();
		var deviceMessage =
			api.systemType.toUpperCase() +
			"_" +
			api.systemVersion +
			"_" +
			api.deviceModel +
			"_" +
			api.appVersion;
		request({
			url:
				"/auth/v2/" +
				getDeviceId() +
				"/" +
				myParam.channelType +
				"/" +
				myParam.apkType,
			values: {
				deviceName: api.uiMode.toUpperCase(),
				user_token: "",
				deviceMessage: deviceMessage
			}
		})
			.then(function(res) {
				// console.log(''+api.uiMode+'-------'+JSON.stringify(res));
				api.setGlobalData({
					key: "uCode",
					value: res.uCode
				});

				if (!argFromAuth) {
					return new Promise(function() {});
				}
			})
			.then(function() {
				isAuth(argFromAuth);
			});
	}

	// 鉴权
	function isAuth(params) {
		return request({
			url: "/user/video/v2/isplay",
			values: _objectSpread2(
				{
					apkType: myParam.apkType,
					channelType: myParam.channelType,
					uniqueStr: api.deviceModel,
					deviceName: api.uiMode.toUpperCase(),
					gradeid: "6802616b-e421-4c05-a5d8-f6cd5edf7272"
				},
				params
			)
		}).then(function(res) {
			// console.log(JSON.stringify(res));
			if (res) {
				if (res.unlogined == 1) {
					authV2(params);
					return new Promise(function() {});
				}
				return res.result;
			}
		});
	}

	// 查询权限
	/*
    @param {type} String :默认pro-输出promise数组，'none'-返回数组·

    */
	function hasPermission(permission, type) {
		if (type === void 0) {
			type = "";
		}
		var resultList = api.hasPermission({
			list: permission
		});

		if (!type) return resultList;
		return Promise.resolve(resultList);
	}

	//创建本地数据库
	function opendb_common() {
		var db = api.require("db");
		db.openDatabase(
			{
				name: "pyLogDB",
				path: "fs://downloadlist.db"
			},
			function(ret, err) {
				if (ret.status) {
					createPyLog();
					// createQmcs();
					// console.log(JSON.stringify(ret)+'--opendb_common');
				}
			}
		);
	}

	//创建本地支付日志表
	function createPyLog() {
		var db = api.require("db");
		var sql_1 =
			"CREATE TABLE if not exists pyLog(id INTEGER PRIMARY KEY AUTOINCREMENT, transactionId varchar(255), receipt TexT, uCode varchar(255),orderId varchar(255),state INTEGER,createdtime datetime,reserve_1 varchar(255),reserve_2 varchar(255),reserve_3 datetime)";
		db.executeSql(
			{
				name: "pyLogDB",
				sql: sql_1
			},
			function(ret, err) {
				if (ret.status) {
					// console.log(JSON.stringify(ret)+'--createPyLog');
					checkDBOrder();
				}
			}
		);
	}

	//掉单处理
	function checkDBOrder() {
		var db = api.require("db");
		db.selectSql(
			{
				name: "pyLogDB",
				sql: "SELECT * FROM pyLog where state=0"
			},
			function(ret, err) {
				if (ret.status) {
					var _loop = function _loop() {
						var orderId = ret.data[i].orderId;
						var transactionId = ret.data[i].transactionId;
						var receipt = ret.data[i].receipt;
						var id = ret.data[i].id;
						request({
							url: "/app/user/order/findOrderstate",
							values: {
								orderid: orderId,
								trade_number_id: transactionId,
								apk_type: myParam.apkType,
								receipt: receipt,
								channelType: myParam.channelType
							}
						}).then(function(res) {
							updateDBPylog(id);
						});
					}; //	        alert(JSON.stringify(ret)+'----checkDBOrder');
					for (var i = 0; i < ret.data.length; i++) {
						_loop();
					}
				}
			}
		);
	}

	//更新本地支付日志支付状态
	function updateDBPylog(id) {
		var db = api.require("db");
		var sql = "update pyLog set state=1 where id=" + id;
		db.executeSql(
			{
				name: "pyLogDB",
				sql: sql
			},
			function(ret, err) {
				if (ret.status);
			}
		);
	}

	// 登录、注册、购买页检测权限
	function checkPms(callback) {
		if (callback === void 0) {
			callback = "";
		}
		var resList = hasPermission(["phone-r"]);
		if (!resList[0].granted) {
			api.confirm(
				{
					title: "提示",
					msg:
						"您未授权IMEI权限，为确保您的虚拟权限能正常使用请您授权获取IMEI，否则无法为您提供服务",
					buttons: ["确定", "取消"]
				},
				function(ret) {
					if (ret.buttonIndex == 1) {
						// 确定
						api.requestPermission(
							{
								list: ["phone-r"]
							},
							function(ret) {
								if (ret.list[0].granted) {
									if (localStorage.getItem("prevStartup") != "1") {
										localStorage.setItem("prevStartup", 1);
									}
									localStorage.removeItem("temporaryUid");
									// $api.rmStorage('temporaryUid');
									api.toast({
										msg: "授权成功",
										duration: 3000,
										location: "middle",
										global: true
									});

									authV2(); // 授权后要重新调默认登录接口
									callback && callback();
								} else {
									noServe();
								}
							}
						);
					} else {
						noServe();
					}
				}
			);
		} else {
			callback && callback();
		}
	}

	function noServe() {
		api.toast({
			msg: "很抱歉，无法为您提供服务",
			duration: 3000,
			location: "middle",
			global: true
		});

		api.closeWin();
	}

	global.wxPlus = api.require("wxPlus");
	global.wxPay = api.require("wxPay");
	global.aliPay = api.require("aliPay");
	var Payment = /*@__PURE__*/ (function(Component) {
		function Payment(props) {
			Component.call(this, props);
			this.data = {
				mode: props.uiMode,
				bgPic:
					"https://3jidi-1251017968.cos.ap-guangzhou.myqcloud.com/upload/pics/ott_3jd_v2/pay/xxzw_s/phone_zw_s_bg_v1.png",
				priceSel: 0,
				priceList: [],
				isAllow: true,
				systemType: "",
				payTypeList: [
					{
						name: "wx",
						type: "wxpay",
						isSel: true
					},

					{
						name: "ali",
						type: "alipay",
						isSel: false
					}
				],

				payType: "wxpay"
			};
		}

		if (Component) Payment.__proto__ = Component;
		Payment.prototype = Object.create(Component && Component.prototype);
		Payment.prototype.constructor = Payment;
		Payment.prototype.apiready = function() {
			checkPms();
			this.data.systemType = api.systemType;
			this.getPriceData();
		};
		Payment.prototype.closeWin = function() {
			api.closeWin();
		};
		Payment.prototype.getPriceData = function() {
			var this$1 = this;

			request(
				{
					url:
						"/app/user/order/apkList/" + myParam.channelType + "/" + myParam.apkType,
					values: {
						auto_grade: "6802616b-e421-4c05-a5d8-f6cd5edf7272",
						platform: "PHONE",
						phone_version: myParam.phone_version
					}
				},

				api.getPrefs({sync: true, key: "sessionId"})
			).then(function(res) {
				// console.log(JSON.stringify(res));
				res.forEach(function(v, i) {
					v.bigPic =
						v.setprice_apk_big_prcture.slice(0, -4) +
						"_zbig" +
						v.setprice_apk_big_prcture.slice(-4);
					v.defPic =
						v.setprice_apk_big_prcture.slice(0, -4) +
						"_onblur" +
						v.setprice_apk_big_prcture.slice(-4);
					v.sel = i === 0 ? true : false;
				});
				this$1.data.priceList = res;
				// this.bgPic = res[0].entity_picture;
			});
		};
		Payment.prototype.priceSel = function(index, isSel, id, ios_productid) {
			if (isSel) {
				return this.confirmOrder(id, ios_productid);
			}
			this.data.priceSel = index;
			this.data.priceList.forEach(function(v, i) {
				v.sel = i === parseInt(index) ? true : false;
			});
			var bigPics = document.getElementById("bigPics");
			bigPics.scrollTo({
				view: "pt" + index,
				animated: true
			});
		};
		Payment.prototype.selPayType = function(payType, idx) {
			this.data.payTypeList.forEach(function(v, i) {
				v.isSel = parseInt(idx) === i ? true : false;
			});
			this.data.payType = payType;
		};
		Payment.prototype.orderNow = function() {
			var priceList = this.data.priceList;
			var current = priceList.filter(function(v) {
				return v.sel;
			})[0];
			this.confirmOrder(current.id, current.ios_productid);
		};
		Payment.prototype.confirmOrder = function(id) {
			var this$1 = this;

			if (this.data.isAllow) {
				this.data.isAllow = false;
				this.order(id)
					.then(function(res) {
						// console.log(JSON.stringify(res));
						if (res.code === "0000") {
							return this$1.findOrderById(res.orderId);
						} else {
							api.hideProgress();
							api.toast({
								msg: "系统繁忙!",
								duration: 3000,
								global: true
							});

							this$1.data.isAllow = true;
							return new Promise(function() {});
						}
					})
					.catch(function(err) {
						api.hideProgress();
						this$1.data.isAllow = true;
						console.log("order error----" + JSON.stringify(err));
					})
					.then(function(res1) {
						// console.log(JSON.stringify(res1));
						if (this$1.data.payType == "wxpay") {
							var wp = res1.wxpay;
							this$1.wxOrder(
								wp.appid,
								wp.prepayid,
								wp.partnerid,
								wp.noncestr,
								wp.timestamp,
								wp.packages,
								wp.sign
							);
						} else {
							this$1.aliOrder(res1.apipay);
						}
					});
			}
		};
		Payment.prototype.order = function(id) {
			api.showProgress({
				//打开开关
				title: "加载中...",
				text: ""
			});

			return request(
				{
					url:
						"/user/order/insert/" +
						id +
						"/" +
						myParam.apkType +
						"/" +
						myParam.channelType
				},
				api.getPrefs({sync: true, key: "sessionId"})
			);
		};
		Payment.prototype.findOrderById = function(orderid) {
			return request(
				{
					url: "/app/user/order/find/" + orderid,
					values: {
						payType: this.data.payType,
						channel_type: myParam.channelType
					}
				},

				api.getPrefs({sync: true, key: "sessionId"})
			);
		};
		Payment.prototype.wxOrder = function(
			appid,
			prepayid,
			partnerid,
			noncestr,
			timestamp,
			packages,
			sign
		) {
			var this$1 = this;

			wxPlus.isInstalled(function(ret, err) {
				// console.log(JSON.stringify(ret))
				api.hideProgress();
				if (ret.installed) {
					wxPay.payOrder(
						{
							apiKey: appid,
							orderId: prepayid,
							mchId: partnerid,
							nonceStr: noncestr,
							timeStamp: timestamp,
							package: packages,
							sign: sign
						},
						function(ret, err) {
							// console.log(JSON.stringify(ret)+'-wxpay')
							if (ret.status) {
								//支付成功
								this$1.orderSuccess();
							} else {
								this$1.data.isAllow = true;
								api.alert({msg: "支付失败"});
							}
						}
					);
				} else {
					this$1.data.isAllow = true;
					api.alert({msg: "当前设备未安装微信客户端"});
				}
			});
		};
		Payment.prototype.aliOrder = function(orderInfo) {
			var this$1 = this;

			api.hideProgress();
			aliPay.payOrder(
				{
					orderInfo: orderInfo
				},
				function(ret, err) {
					if (ret.code == "9000") {
						this$1.orderSuccess();
					} else {
						this$1.data.isAllow = true;
						api.alert({msg: "支付失败"});
					}
				}
			);
		};
		Payment.prototype.orderSuccess = function() {
			api.toast({
				msg: "支付成功",
				duration: 3000,
				global: true
			});

			api.sendEvent({name: "toIndex"});
			this.closeWin();
		};
		Payment.prototype.render = function() {
			var this$1 = this;
			return apivm.h(
				"view",
				{class: "page"},
				apivm.h("image", {
					src: this.data.bgPic,
					thumbnail: "false",
					mode: "aspectFill",
					class: "bg"
				}),
				this.data.systemType == "ios"
					? apivm.h(
							"a-nav-bar",
							{
								title: "支付中心",
								"left-arrow": true,
								height: "64",
								"title-size": "26",
								"title-color": "#fff",
								"hide-line": true,
								style: "background-color: #ee9c58",
								"onClick-left": this.closeWin
							},
							apivm.h(
								"template",
								{_slot: "left"},
								apivm.h("a-icon", {name: "../../image/booklist/backTo.png", size: "40"})
							)
					  )
					: this.data.systemType == "android"
					? apivm.h(
							"view",
							{class: "header"},
							apivm.h("image", {
								mode: "aspectFit",
								src: "../../image/booklist/backTo.png",
								class: "back",
								onClick: this.closeWin
							}),
							apivm.h("text", {class: "header_text"}, "支付中心"),
							apivm.h("view", {class: "back"})
					  )
					: null,

				apivm.h(
					"view",
					{class: "container"},

					apivm.h(
						"scroll-view",
						{
							class: "payType",
							id: "bigPics",
							"show-scrollbar": "false",
							"scroll-enabled": "false",
							style: "max-height:" + (this.data.mode == "phone" ? 260 : 500) + "px"
						},
						(Array.isArray(this.data.priceList)
							? this.data.priceList
							: Object.values(this.data.priceList)
						).map(function(item$1, index$1) {
							return apivm.h("image", {
								id: "pt" + index$1,
								thumbnail: "false",
								class: "bigPic",
								src: item$1.bigPic
							});
						})
					),

					apivm.h(
						"scroll-view",
						{class: "paySelect", "show-scrollbar": "false"},
						(Array.isArray(this.data.priceList)
							? this.data.priceList
							: Object.values(this.data.priceList)
						).map(function(item$1, index$1) {
							return apivm.h(
								"view",
								{
									class: "selBtn",
									onClick: function() {
										return this$1.priceSel(
											index$1,
											item$1.sel,
											item$1.id,
											item$1.ios_productid
										);
									},
									style: this$1.data.priceSel == index$1 ? "width:100%" : "width: 90%;"
								},
								apivm.h("image", {
									class: "def",
									style: {display: this$1.data.priceSel != index$1 ? "flex" : "none"},
									thumbnail: "false",
									src: item$1.defPic
								}),
								apivm.h("image", {
									class: "sel",
									style: {display: this$1.data.priceSel == index$1 ? "flex" : "none"},
									thumbnail: "false",
									src: item$1.setprice_apk_big_prcture
								})
							);
						})
					),
					apivm.h(
						"view",
						{class: "payType_wrap"},
						(Array.isArray(this.data.payTypeList)
							? this.data.payTypeList
							: Object.values(this.data.payTypeList)
						).map(function(ptype, idx) {
							return apivm.h(
								"view",
								{
									class: "paytype",
									onClick: function() {
										return this$1.selPayType(ptype.type, idx);
									}
								},
								apivm.h("image", {
									mode: "widthFix",
									style: {display: !ptype.isSel ? "flex" : "none"},
									src: "../../image/android_order/" + ptype.name + "Def.png"
								}),
								apivm.h("image", {
									mode: "widthFix",
									style: {display: ptype.isSel ? "flex" : "none"},
									src: "../../image/android_order/" + ptype.name + "Sel.png"
								})
							);
						})
					),
					apivm.h(
						"a-button",
						{
							type: "warning",
							size: "large",
							disabled: !this.data.isAllow,
							onClick: this.orderNow
						},
						"立即支付"
					)
				)
			);
		};

		return Payment;
	})(Component);
	Payment.css = {
		".page": {height: "100%", position: "relative"},
		".bg": {
			width: "100%",
			height: "100%",
			position: "absolute",
			top: "0",
			left: "0"
		},
		".header": {
			width: "100%",
			height: "64px",
			position: "absolute",
			top: "0",
			left: "0",
			padding: "0 2%",
			boxSizing: "border-box",
			flexDirection: "row",
			justifyContent: "space-between",
			alignItems: "center"
		},
		".back": {width: "40px", height: "40px"},
		".header_text": {color: "#fff", fontSize: "26px", fontWeight: "700"},
		".container": {
			width: "95%",
			height: "86%",
			position: "absolute",
			right: "2.5%",
			top: "12%"
		},
		".payType": {width: "100%", height: "45%", alignItems: "center"},
		".bigPic": {height: "100%"},
		".paySelect": {
			width: "100%",
			maxWidth: "520px",
			height: "auto",
			maxHeight: "45%",
			alignItems: "center",
			margin: "auto"
		},
		".selBtn": {width: "90%", margin: "0 auto 10px"},
		".payType_wrap": {
			width: "95%",
			margin: "auto",
			flexDirection: "row",
			justifyContent: "space-between",
			alignItems: "center"
		},
		".paytype": {width: "47.5%"},
		"@media (min-width: 768px)": {".payType": {maxHeight: "500px"}}
	};
	apivm.define("payment", Payment);
	apivm.render(apivm.h("payment", null), "body");
})();
